==> seedsui-react-5.5.1.tgz: package/es/DatePicker/RangeModal/index.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
var _excluded = ["portal", "getComboDOM", "value", "list", "onBeforeChange", "onChange", "visible", "maskClosable", "onVisibleChange", "separator", "caption", "min", "max", "type", "ranges", "TooltipProps", "StartComboProps", "EndComboProps", "onError", "children"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useImperativeHandle, useRef, useState, forwardRef, Fragment } from 'react';
import Tooltip from './../../Tooltip';
import locale from './../../locale';
import DateComboUtils from './../Combo/Utils';
import DateModalUtils from './../Modal/Utils';
import RangeUtils from './Utils';
import RangeModal from './RangeModal';
var range = 90; // 日期区间选择

var Modal = forwardRef(function (_ref, ref) {
  var portal = _ref.portal,
      getComboDOM = _ref.getComboDOM,
      value = _ref.value,
      list = _ref.list,
      onBeforeChange = _ref.onBeforeChange,
      onChange = _ref.onChange,
      _ref$visible = _ref.visible,
      visible = _ref$visible === void 0 ? false : _ref$visible,
      _ref$maskClosable = _ref.maskClosable,
      maskClosable = _ref$maskClosable === void 0 ? true : _ref$maskClosable,
      onVisibleChange = _ref.onVisibleChange,
      _ref$separator = _ref.separator,
      separator = _ref$separator === void 0 ? '' : _ref$separator,
      _ref$caption = _ref.caption,
      caption = _ref$caption === void 0 ? locale('自定义时间', 'datepicker-tooltip_custom_date') : _ref$caption,
      min = _ref.min,
      max = _ref.max,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'date' : _ref$type,
      ranges = _ref.ranges,
      _ref$TooltipProps = _ref.TooltipProps,
      TooltipProps = _ref$TooltipProps === void 0 ? {} : _ref$TooltipProps,
      _ref$StartComboProps = _ref.StartComboProps,
      StartComboProps = _ref$StartComboProps === void 0 ? {} : _ref$StartComboProps,
      _ref$EndComboProps = _ref.EndComboProps,
      EndComboProps = _ref$EndComboProps === void 0 ? {} : _ref$EndComboProps,
      onError = _ref.onError,
      children = _ref.children,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  // 节点
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    var _rootRef$current;

    return {
      getRootDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current = rootRef.current) === null || _rootRef$current === void 0 ? void 0 : _rootRef$current.getRootDOM
    };
  }); // 自定义日期数据

  var _useState = useState(false),
      modalVisible = _useState[0],
      setModalVisible = _useState[1]; // 修改


  function handleChange(newValue) {
    if (newValue.length !== 2) return false;
    return new Promise( /*#__PURE__*/function () {
      var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(resolve) {
        var i, date, fmt, startDate, endDate, dateName, goOn;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                i = 0;

              case 1:
                if (!(i < newValue.length)) {
                  _context.next = 11;
                  break;
                }

                date = newValue[i];
                date = DateModalUtils.validateDate(date, {
                  type: type,
                  min: min,
                  max: max,
                  onError: onError
                });

                if (!(date === false)) {
                  _context.next = 7;
                  break;
                }

                resolve(false);
                return _context.abrupt("return");

              case 7:
                newValue[i] = date;

              case 8:
                i++;
                _context.next = 1;
                break;

              case 11:
                if (RangeUtils.validateRange(newValue, {
                  range: typeof ranges === 'number' ? ranges : range,
                  onError: onError
                })) {
                  _context.next = 14;
                  break;
                }

                resolve(false);
                return _context.abrupt("return");

              case 14:
                // 获取日期名称: 今日、昨日、本月等
                fmt = DateComboUtils.getFormat(type);
                startDate = newValue[0];
                endDate = newValue[1];

                if (startDate instanceof Date) {
                  startDate = startDate.format(fmt);
                }

                if (endDate instanceof Date) {
                  endDate = endDate.format(fmt);
                }

                dateName = startDate && endDate ? RangeUtils.getDateName(startDate, endDate) : ''; // 修改提示

                if (!(typeof onBeforeChange === 'function')) {
                  _context.next = 27;
                  break;
                }

                _context.next = 23;
                return onBeforeChange(newValue, dateName);

              case 23:
                goOn = _context.sent;

                if (goOn) {
                  _context.next = 27;
                  break;
                }

                resolve(false);
                return _context.abrupt("return");

              case 27:
                // 触发onChange事件
                if (onChange) {
                  onChange(newValue, dateName);
                }

                if (onVisibleChange) onVisibleChange(false);
                resolve(true);

              case 30:
              case "end":
                return _context.stop();
            }
          }
        }, _callee);
      }));

      return function (_x) {
        return _ref2.apply(this, arguments);
      };
    }());
  } // 显示自定义弹框


  function showModal(currentRange) {
    // 设置区间不能超过?天
    range = currentRange;
    setModalVisible(true);
    if (onVisibleChange) onVisibleChange();
  } // 快捷修改日期


  function handleTooltipChange(_x2) {
    return _handleTooltipChange.apply(this, arguments);
  } // 修改自定义日期


  function _handleTooltipChange() {
    _handleTooltipChange = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(newValue) {
      var goOn;
      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              _context2.next = 2;
              return handleChange(newValue);

            case 2:
              goOn = _context2.sent;

              if (!(goOn === false)) {
                _context2.next = 5;
                break;
              }

              return _context2.abrupt("return");

            case 5:
              if (onVisibleChange) onVisibleChange(false);

            case 6:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2);
    }));
    return _handleTooltipChange.apply(this, arguments);
  }

  function handleModalChange(_x3) {
    return _handleModalChange.apply(this, arguments);
  } // 构建内容


  function _handleModalChange() {
    _handleModalChange = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3(newValue) {
      var goOn;
      return _regeneratorRuntime.wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              _context3.next = 2;
              return handleChange(newValue);

            case 2:
              goOn = _context3.sent;

              if (!(goOn === false)) {
                _context3.next = 5;
                break;
              }

              return _context3.abrupt("return");

            case 5:
              // 隐藏自定义日期框
              setModalVisible(false);
              if (onVisibleChange) onVisibleChange(false);

            case 7:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3);
    }));
    return _handleModalChange.apply(this, arguments);
  }

  function getTooltipContent() {
    if (Object.prototype.toString.call(ranges) !== '[object Object]') return null;
    return Object.entries(ranges).map(function (item) {
      var key = item[0];
      var range = item[1];

      if (typeof range === 'number') {
        return /*#__PURE__*/React.createElement("div", {
          className: "datepicker-tooltip-option",
          key: key,
          onClick: function onClick() {
            return showModal(range);
          }
        }, locale('自定义时间', 'datepicker-tooltip_custom_date'));
      }

      return /*#__PURE__*/React.createElement("div", {
        key: key,
        className: "datepicker-tooltip-option",
        onClick: function onClick(e) {
          handleTooltipChange(range);
          e.stopPropagation();
        }
      }, key);
    });
  }

  return /*#__PURE__*/React.createElement(Fragment, null, Object.prototype.toString.call(ranges) === '[object Object]' && /*#__PURE__*/React.createElement(Tooltip, _extends({
    content: getTooltipContent(),
    getChildrenDOM: getComboDOM,
    visible: visible,
    maskClosable: maskClosable,
    onVisibleChange: onVisibleChange
  }, TooltipProps || {}), children), /*#__PURE__*/React.createElement(RangeModal, _extends({
    ref: rootRef,
    separator: separator,
    caption: caption,
    min: min,
    max: max,
    type: type,
    value: value,
    visible: Object.prototype.toString.call(ranges) !== '[object Object]' ? visible : modalVisible,
    maskClosable: maskClosable,
    onVisibleChange: Object.prototype.toString.call(ranges) !== '[object Object]' ? onVisibleChange : setModalVisible,
    StartComboProps: StartComboProps,
    EndComboProps: EndComboProps,
    onChange: handleModalChange,
    onError: onError
  }, props)));
});
export default Modal;

==> seedsui-react-5.5.3.tgz: package/es/DatePicker/RangeModal/index.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
var _excluded = ["portal", "getComboDOM", "value", "list", "onBeforeChange", "onChange", "visible", "maskClosable", "onVisibleChange", "separator", "caption", "min", "max", "type", "ranges", "daysLimit", "TooltipProps", "StartComboProps", "EndComboProps", "onError", "children"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useImperativeHandle, useRef, useState, forwardRef, Fragment } from 'react';
import Tooltip from './../../Tooltip';
import locale from './../../locale';
import DateComboUtils from './../Combo/Utils';
import DateModalUtils from './../Modal/Utils';
import RangeUtils from './Utils';
import RangeModal from './RangeModal'; // 日期区间选择

var Modal = forwardRef(function (_ref, ref) {
  var portal = _ref.portal,
      getComboDOM = _ref.getComboDOM,
      value = _ref.value,
      list = _ref.list,
      onBeforeChange = _ref.onBeforeChange,
      onChange = _ref.onChange,
      _ref$visible = _ref.visible,
      visible = _ref$visible === void 0 ? false : _ref$visible,
      _ref$maskClosable = _ref.maskClosable,
      maskClosable = _ref$maskClosable === void 0 ? true : _ref$maskClosable,
      onVisibleChange = _ref.onVisibleChange,
      _ref$separator = _ref.separator,
      separator = _ref$separator === void 0 ? '' : _ref$separator,
      _ref$caption = _ref.caption,
      caption = _ref$caption === void 0 ? locale('自定义时间', 'datepicker-tooltip_custom_date') : _ref$caption,
      min = _ref.min,
      max = _ref.max,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'date' : _ref$type,
      ranges = _ref.ranges,
      _ref$daysLimit = _ref.daysLimit,
      daysLimit = _ref$daysLimit === void 0 ? 90 : _ref$daysLimit,
      _ref$TooltipProps = _ref.TooltipProps,
      TooltipProps = _ref$TooltipProps === void 0 ? {} : _ref$TooltipProps,
      _ref$StartComboProps = _ref.StartComboProps,
      StartComboProps = _ref$StartComboProps === void 0 ? {} : _ref$StartComboProps,
      _ref$EndComboProps = _ref.EndComboProps,
      EndComboProps = _ref$EndComboProps === void 0 ? {} : _ref$EndComboProps,
      onError = _ref.onError,
      children = _ref.children,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  // 节点
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    var _rootRef$current;

    return {
      getRootDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current = rootRef.current) === null || _rootRef$current === void 0 ? void 0 : _rootRef$current.getRootDOM
    };
  }); // 自定义日期数据

  var _useState = useState(false),
      modalVisible = _useState[0],
      setModalVisible = _useState[1]; // 修改


  function handleChange(newValue) {
    if (newValue.length !== 2) return false;
    return new Promise( /*#__PURE__*/function () {
      var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(resolve) {
        var i, date, fmt, startDate, endDate, dateName, goOn;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                i = 0;

              case 1:
                if (!(i < newValue.length)) {
                  _context.next = 11;
                  break;
                }

                date = newValue[i];
                date = DateModalUtils.validateDate(date, {
                  type: type,
                  min: min,
                  max: max,
                  onError: onError
                });

                if (!(date === false)) {
                  _context.next = 7;
                  break;
                }

                resolve(false);
                return _context.abrupt("return");

              case 7:
                newValue[i] = date;

              case 8:
                i++;
                _context.next = 1;
                break;

              case 11:
                if (RangeUtils.validateRange(newValue, {
                  daysLimit: typeof ranges === 'number' ? ranges : daysLimit,
                  onError: onError
                })) {
                  _context.next = 14;
                  break;
                }

                resolve(false);
                return _context.abrupt("return");

              case 14:
                // 获取日期名称: 今日、昨日、本月等
                fmt = DateComboUtils.getFormat(type);
                startDate = newValue[0];
                endDate = newValue[1];

                if (startDate instanceof Date) {
                  startDate = startDate.format(fmt);
                }

                if (endDate instanceof Date) {
                  endDate = endDate.format(fmt);
                }

                dateName = startDate && endDate ? RangeUtils.getDateName(startDate, endDate) : ''; // 修改提示

                if (!(typeof onBeforeChange === 'function')) {
                  _context.next = 27;
                  break;
                }

                _context.next = 23;
                return onBeforeChange(newValue, dateName);

              case 23:
                goOn = _context.sent;

                if (goOn) {
                  _context.next = 27;
                  break;
                }

                resolve(false);
                return _context.abrupt("return");

              case 27:
                // 触发onChange事件
                if (onChange) {
                  onChange(newValue, dateName);
                }

                if (onVisibleChange) onVisibleChange(false);
                resolve(true);

              case 30:
              case "end":
                return _context.stop();
            }
          }
        }, _callee);
      }));

      return function (_x) {
        return _ref2.apply(this, arguments);
      };
    }());
  } // 显示自定义弹框


  function showModal(range) {
    setModalVisible(range);
    if (onVisibleChange) onVisibleChange(false);
  } // 快捷修改日期


  function handleTooltipChange(_x2) {
    return _handleTooltipChange.apply(this, arguments);
  } // 修改自定义日期


  function _handleTooltipChange() {
    _handleTooltipChange = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(newValue) {
      var goOn;
      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              _context2.next = 2;
              return handleChange(newValue);

            case 2:
              goOn = _context2.sent;

              if (!(goOn === false)) {
                _context2.next = 5;
                break;
              }

              return _context2.abrupt("return");

            case 5:
              if (onVisibleChange) onVisibleChange(false);

            case 6:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2);
    }));
    return _handleTooltipChange.apply(this, arguments);
  }

  function handleModalChange(_x3) {
    return _handleModalChange.apply(this, arguments);
  } // 构建内容


  function _handleModalChange() {
    _handleModalChange = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3(newValue) {
      var goOn;
      return _regeneratorRuntime.wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              _context3.next = 2;
              return handleChange(newValue);

            case 2:
              goOn = _context3.sent;

              if (!(goOn === false)) {
                _context3.next = 5;
                break;
              }

              return _context3.abrupt("return");

            case 5:
              // 隐藏自定义日期框
              setModalVisible(false);
              if (onVisibleChange) onVisibleChange(false);

            case 7:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3);
    }));
    return _handleModalChange.apply(this, arguments);
  }

  function getTooltipContent() {
    if (justModal()) return null;
    return Object.entries(ranges).map(function (item) {
      var key = item[0];
      var range = item[1];

      if (!Array.isArray(range) || range.length !== 2) {
        return /*#__PURE__*/React.createElement("div", {
          className: "datepicker-tooltip-option",
          key: key,
          onClick: function onClick() {
            return showModal(range || true);
          }
        }, key);
      }

      return /*#__PURE__*/React.createElement("div", {
        key: key,
        className: "datepicker-tooltip-option",
        onClick: function onClick(e) {
          handleTooltipChange(range);
          e.stopPropagation();
        }
      }, key);
    });
  } // 判断是否为直接弹窗, 直接弹窗则返回弹框所需的值


  function justModal() {
    // 非对象直接弹框
    if (Object.prototype.toString.call(ranges) !== '[object Object]') return true; // 数组只有一项, 且为自定义弹框时直接弹框

    var rangesArr = Object.entries(ranges);

    if (!Array.isArray(rangesArr) || rangesArr.length <= 1) {
      if (Array.isArray(rangesArr) && rangesArr.length == 1) {
        if (Array.isArray(rangesArr[0]) && rangesArr[0].length === 2) {
          // 值为[xx, xx]则非自定义弹框
          // let key = rangesArr[0][0]
          var range = rangesArr[0][1];

          if (Array.isArray(range) && range.length === 2) {
            return false;
          } // 值为其它则为自定义弹框


          return range;
        }
      }

      return true;
    }

    return false;
  }

  return /*#__PURE__*/React.createElement(Fragment, null, !justModal() && /*#__PURE__*/React.createElement(Tooltip, _extends({
    content: getTooltipContent(),
    getChildrenDOM: getComboDOM,
    visible: visible,
    maskClosable: maskClosable,
    onVisibleChange: onVisibleChange
  }, TooltipProps || {}), children), /*#__PURE__*/React.createElement(RangeModal, _extends({
    ref: rootRef,
    separator: separator,
    caption: caption,
    min: min,
    max: max,
    type: type,
    value: value,
    visible: justModal() ? visible ? justModal() : false : modalVisible,
    maskClosable: maskClosable,
    onVisibleChange: justModal() ? onVisibleChange : setModalVisible,
    StartComboProps: StartComboProps,
    EndComboProps: EndComboProps,
    onChange: handleModalChange,
    onError: onError
  }, props)));
});
export default Modal;
